@@ -3,7 +3,7 @@ import logging
 from typing import AsyncGenerator, Callable, Mapping
 
 from sqlalchemy import MetaData
-from sqlalchemy.ext.asyncio import AsyncSession, AsyncEngine, async_engine_from_config
+from sqlalchemy.ext.asyncio import AsyncEngine, AsyncSession, async_engine_from_config
 from sqlalchemy.ext.asyncio.session import async_sessionmaker
 from sqlalchemy.orm import declarative_base
 
@@ -31,6 +31,7 @@ class AsyncSessionManager:
     def async_engine_from_db_settings(self, name):
         db_settings = self.get_db_settings(name)
         configuration = db_settings.model_dump(by_alias=True)
+        configuration['url'] = str(configuration['url'])
         engine = async_engine_from_config(configuration, prefix='')
 
         return engine
@@ -51,20 +52,23 @@ class AsyncSessionManager:
         except KeyError:
             logger.debug(f'Creating session maker: {name}')
             engine = self.get_engine(name)
-            session_maker = async_sessionmaker(engine)
+            session_maker = async_sessionmaker(engine, expire_on_commit=False)
             self.session_makers[name] = session_maker
 
         return session_maker
 
     def get_async_session(self, name: str) -> Callable[[], AsyncGenerator[AsyncSession, None]]:
         async def get_session() -> AsyncGenerator[AsyncSession, None]:
-            async with self.get_session_maker(name) as session:
+            session_maker = self.get_session_maker(name)
+
+            async with session_maker() as session:
                 yield session
 
         return get_session
 
     def get_session_context(self, name: str):
-        return contextlib.asynccontextmanager(lambda: self.get_async_session(name)())
+        # TODO: cache
+        return contextlib.asynccontextmanager(self.get_async_session(name))
 
 
 async def is_healthy(engine: AsyncEngine) -> bool:
